%% inseti: example
% Example of input parameters to run |start| not with default parameters.
%
% This file uses the extended soft-shrinkage operator (via |seti.invNo = 1|) 
% and is analogous to <example.html>, that uses the primal-dual algorithm 
% (via |seti.invNo = 6|). (For the different inversion types see
% <setInvType.html>.)
%
% Apart from |seti.tau| and |seti.nOut| the parameters of this file are not specially tuned. 
% It is a demonstration of default values.
%
%% Input Parameters of struct |seti|
% Note that this are *some*, but *not all* input parameters.

% -- dirname: suffix
seti.dirSuffix = '';

% -- setGrid
seti.dim = 2;
seti.rCD = 0.2;
seti.nCD = 256;

% -- setKernel
seti.k = 250;
seti.model = 'helmholtz';

% -- setContrast
seti.contrast = 'cornerBallSparse2D';

% -- expSetup (set experimental set-up)
seti.incPntsType = 'circle';
seti.measPntsType = 'circle';
seti.incNb = 35; 
seti.measNb = 35;
seti.radSrc = 5;
seti.radMeas = 5;
seti.incType = 'pointSource';
seti.measType = 'nearField';

% -- reconstruction
seti.invNo = 1; % in comparison to 6 in example.m
seti.delta = 0.01;
seti.physBounds = [-1,3,0,3];
seti.alpha = 0.005; % default in the case of soft-shrinkage (without wavelets)
seti.useDis = 1;
seti.tau = 5; % higher than in example.m (was 1.5 until 20190321, i.e. smaller than in example.m)
seti.nOut = 500; % shrinkage needs a lot more iterations than primal-dual algorithm (was 5000 until 20190321)

% -- reconstruction with shrinkage
% In comparison to primal-dual algorithm it is possible to set a step size
% by Barzilai-Borwein and a step size refinement by Armijo rule.
% A description is in minShrink.m
% It is recommended leaving Barzilai-Borwein and Armijo rule off.
seti.stepsizeStart = 1;
seti.useBarBor = 0;
seti.useArmijo = 0;
